@@ -14,7 +14,7 @@ import io
 import os
 import sys
 import time
-from urllib.parse import unquote, urlsplit
+from urllib.parse import urlsplit
 
 import aiohttp
 from aiohttp import server
@@ -128,7 +128,7 @@ class WSGIServerHttpProtocol(server.ServerHttpProtocol):
         if script_name:
             path_info = path_info.split(script_name, 1)[-1]
 
-        environ['PATH_INFO'] = unquote(path_info)
+        environ['PATH_INFO'] = path_info
         environ['SCRIPT_NAME'] = script_name
 
         environ['async.reader'] = self.reader
