@@ -1,6 +1,7 @@
 """Tests for aiohttp/server.py"""
 
 import asyncio
+import socket
 import unittest
 import unittest.mock
 
@@ -47,11 +48,38 @@ class HttpServerProtocolTests(unittest.TestCase):
         srv._keep_alive_handle = keep_alive_handle
         timeout_handle = unittest.mock.Mock()
         srv._timeout_handle = timeout_handle
-        srv.transport = unittest.mock.Mock()
+        transport = srv.transport = unittest.mock.Mock()
         srv.writer = unittest.mock.Mock()
 
         srv.closing()
-        self.assertTrue(srv.transport.close.called)
+        self.assertTrue(transport.close.called)
+        self.assertIsNone(srv.transport)
+
+        self.assertIsNotNone(srv._keep_alive_handle)
+        self.assertFalse(keep_alive_handle.cancel.called)
+
+        self.assertIsNotNone(srv._timeout_handle)
+        self.assertFalse(timeout_handle.cancel.called)
+
+    def test_double_closing(self):
+        srv = server.ServerHttpProtocol(loop=self.loop)
+        srv._keep_alive = True
+
+        keep_alive_handle = unittest.mock.Mock()
+        srv._keep_alive_handle = keep_alive_handle
+        timeout_handle = unittest.mock.Mock()
+        srv._timeout_handle = timeout_handle
+        transport = srv.transport = unittest.mock.Mock()
+        srv.writer = unittest.mock.Mock()
+
+        srv.closing()
+        self.assertTrue(transport.close.called)
+        self.assertIsNone(srv.transport)
+
+        transport.reset_mock()
+        srv.closing()
+        self.assertFalse(transport.close.called)
+        self.assertIsNone(srv.transport)
 
         self.assertIsNotNone(srv._keep_alive_handle)
         self.assertFalse(keep_alive_handle.cancel.called)
@@ -65,6 +93,32 @@ class HttpServerProtocolTests(unittest.TestCase):
 
         srv.connection_made(unittest.mock.Mock())
         self.assertIsNotNone(srv._request_handler)
+        self.assertIsNotNone(srv._timeout_handle)
+
+    def test_connection_made_without_timeout(self):
+        srv = server.ServerHttpProtocol(loop=self.loop, timeout=0)
+
+        srv.connection_made(unittest.mock.Mock())
+        self.assertIsNone(srv._timeout_handle)
+
+    def test_connection_made_with_keepaplive(self):
+        srv = server.ServerHttpProtocol(loop=self.loop)
+
+        sock = unittest.mock.Mock()
+        transport = unittest.mock.Mock()
+        transport.get_extra_info.return_value = sock
+        srv.connection_made(transport)
+        sock.setsockopt.assert_called_with(socket.SOL_SOCKET,
+                                           socket.SO_KEEPALIVE, 1)
+
+    def test_connection_made_without_keepaplive(self):
+        srv = server.ServerHttpProtocol(loop=self.loop, tcp_keepalive=False)
+
+        sock = unittest.mock.Mock()
+        transport = unittest.mock.Mock()
+        transport.get_extra_info.return_value = sock
+        srv.connection_made(transport)
+        self.assertFalse(sock.setsockopt.called)
 
     def test_data_received(self):
         srv = server.ServerHttpProtocol(loop=self.loop)
@@ -445,3 +499,35 @@ class HttpServerProtocolTests(unittest.TestCase):
         srv.log_access(None, None, None, None)
 
         self.assertTrue(srv.log.error.called)
+
+    def test_log_access_disabled(self):
+        transport = unittest.mock.Mock()
+
+        srv = server.ServerHttpProtocol(loop=self.loop, access_log=None)
+        srv.connection_made(transport)
+        srv.log = unittest.mock.Mock()
+
+        message = unittest.mock.Mock()
+        message.headers = []
+        message.version = (1, 1)
+        srv.log_access(None, None, None, None)
+
+        self.assertFalse(srv.log.error.called)
+
+    def test_cancel_not_connected_handler(self):
+        srv = server.ServerHttpProtocol(loop=self.loop)
+        srv.cancel_slow_request()
+
+    def test_srv_process_request_without_timeout(self):
+        transport = unittest.mock.Mock()
+        srv = server.ServerHttpProtocol(timeout=0, loop=self.loop)
+        srv.connection_made(transport)
+        self.assertIsNone(srv._timeout_handle)
+
+        srv.reader.feed_data(
+            b'GET / HTTP/1.0\r\n'
+            b'Host: example.com\r\n\r\n')
+
+        self.loop.run_until_complete(srv._request_handler)
+        self.assertTrue(transport.close.called)
+        self.assertIsNone(srv._timeout_handle)
